@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-dashboard.c,v 1.2.6.1 2004/09/26 16:22:39 chpe Exp $
+ *  $Id: ephy-dashboard.c,v 1.5 2005/01/28 22:29:19 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-dashboard-extension.h"
 #include "ephy-debug.h"
@@ -34,7 +32,7 @@ G_MODULE_EXPORT GType register_module (GTypeModule *module);
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
-	LOG ("Registering DashboardExtension")
+	LOG ("Registering DashboardExtension");
 
 	return ephy_dashboard_extension_register_type (module);
 }
