@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ErrorViewerConsoleListener.cpp,v 1.11.2.2 2005/03/30 19:30:13 chpe Exp $
+ *  $Id: ErrorViewerConsoleListener.cpp,v 1.11.2.3 2005/04/07 11:47:07 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -27,9 +27,9 @@
 
 #include "ErrorViewerConsoleListener.h"
 
-#define MOZILLA_STRICT_API
+#undef MOZILLA_INTERNAL_API
 #include <nsEmbedString.h>
-#undef MOZILLA_STRICT_API
+#define MOZILLA_INTERNAL_API 1
 #include <nsCOMPtr.h>
 #include <nsMemory.h>
 
