@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ErrorViewerURICheckerObserver.cpp,v 1.8 2004/12/08 15:33:52 chpe Exp $
+ *  $Id: ErrorViewerURICheckerObserver.cpp,v 1.8.2.1 2005/04/07 11:47:07 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -26,9 +26,9 @@
 
 #include "ErrorViewerURICheckerObserver.h"
 
-#define MOZILLA_STRICT_API
+#undef MOZILLA_INTERNAL_API
 #include <nsEmbedString.h>
-#undef MOZILLA_STRICT_API
+#define MOZILLA_INTERNAL_API 1
 #include <nsCOMPtr.h>
 #include <nsIChannel.h>
 #include <nsIDOMHTMLAnchorElement.h>
